import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { $ } from "@typespec/compiler/experimental/typekit";
import { FunctionDeclaration, TypeExpression } from "@typespec/emitter-framework/typescript";
import { getClientcontextDeclarationRef } from "./client-context/client-context-declaration.js";
import { HttpRequest } from "./http-request.js";
import { HttpResponse } from "./http-response.js";
import { OperationOptionsDeclaration } from "./operation-options.js";
import { getOperationParameters } from "./operation-parameters.js";
export function ClientOperations(props) {
  const namePolicy = ts.useTSNamePolicy();
  const clientOperations = props.client.operations;
  const fileName = namePolicy.getName(props.client.name + "Operations", "variable");
  if (clientOperations.length === 0) {
    return null;
  }
  return _$createComponent(ts.SourceFile, {
    path: `${fileName}.ts`,
    get children() {
      return _$createComponent(ay.For, {
        each: clientOperations,
        children: operation => _$createComponent(ClientOperation, {
          clientOperation: operation
        })
      });
    }
  });
}
export function ClientOperation(props) {
  const client = props.clientOperation.client;
  const returnType = $.httpOperation.getReturnType(props.clientOperation.httpOperation);
  const responseRefkey = ay.refkey(props.clientOperation, "http-response");
  const clientContextInterfaceRef = getClientcontextDeclarationRef(client);
  const signatureParams = {
    client: {
      type: clientContextInterfaceRef,
      refkey: ay.refkey(client, "client")
    },
    ...getOperationParameters(props.clientOperation.httpOperation)
  };
  return [_$createComponent(OperationOptionsDeclaration, {
    get operation() {
      return props.clientOperation.httpOperation;
    }
  }), _$createComponent(FunctionDeclaration, {
    "export": true,
    async: true,
    get type() {
      return props.clientOperation.httpOperation.operation;
    },
    get returnType() {
      return _$createComponent(TypeExpression, {
        type: returnType
      });
    },
    parametersMode: "replace",
    parameters: signatureParams,
    get children() {
      return [_$createComponent(HttpRequest, {
        get operation() {
          return props.clientOperation;
        },
        responseRefkey: responseRefkey
      }), _$createComponent(HttpResponse, {
        get operation() {
          return props.clientOperation;
        },
        responseRefkey: responseRefkey
      })];
    }
  }), ";"];
}
//# sourceMappingURL=client-operation.js.map