import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import * as ef from "@typespec/emitter-framework/typescript";
import { JsonTransform } from "./json/json-transform.js";
export function getTransformDeclarationRef(operaion) {
  if (operaion.httpOperation.parameters.body?.bodyKind === "single") {
    return ef.getTypeTransformerRefkey(operaion.httpOperation.parameters.body.type, "transport");
  }
  return ay.refkey(operaion, "transform");
}
export function TransformDeclaration(props) {
  const refkey = props.refkey ?? getTransformDeclarationRef(props.operation);
  return [_$createComponent(TransformToTransportDeclaration, {
    get operation() {
      return props.operation;
    },
    refkey: refkey
  })];
}
export function SingleBodyTransformDeclaration(props) {
  const inputRef = ay.refkey(props.payload, "property");
  const payloadParameter = {
    type: _$createComponent(ef.TypeExpression, {
      get type() {
        return props.payload.type;
      }
    }),
    refkey: inputRef
  };
  return _$createComponent(ts.FunctionDeclaration, {
    "export": true,
    get name() {
      return props.name;
    },
    parameters: {
      payload: payloadParameter
    },
    get refkey() {
      return props.refkey;
    },
    get children() {
      return ["return ", _$createComponent(JsonTransform, {
        itemRef: inputRef,
        target: "transport",
        get type() {
          return props.payload.type;
        }
      }), "!;"];
    }
  });
}
function TransformToTransportDeclaration(props) {
  const requestPayload = props.operation.httpOperation.parameters.body;
  if (!requestPayload || !requestPayload.property) {
    return;
  }
  if (requestPayload.bodyKind === "file") return;
  const namePolicy = ts.useTSNamePolicy();
  const name = namePolicy.getName(`${props.operation.name}_payload_to_transport`, "function");
  if (requestPayload.bodyKind === "multipart") {
    return null;
  }
  return _$createComponent(SingleBodyTransformDeclaration, {
    get operation() {
      return props.operation;
    },
    payload: requestPayload,
    get refkey() {
      return props.refkey;
    },
    name: name
  });
}
//# sourceMappingURL=operation-transform-declaration.js.map