import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { writeOutput } from "@typespec/emitter-framework";
import { OperationsDirectory } from "./components/client-directory.js";
import { Client } from "./components/client.js";
import { Models } from "./components/models.js";
import { Output } from "./components/output.js";
import { ModelSerializers } from "./components/serializers.js";
import { Interfaces } from "./components/static-helpers/interfaces.js";
import { MultipartHelpers } from "./components/static-helpers/multipart-helpers.js";
import { RestError } from "./components/static-helpers/rest-error.js";
/**
 * Main function to handle the emission process.
 * @param context - The context for the emission process.
 */
export async function $onEmit(context) {
  const packageName = context.options["package-name"] ?? "test-package";
  const output = _$createComponent(Output, {
    get children() {
      return _$createComponent(ts.PackageDirectory, {
        name: packageName,
        version: "1.0.0",
        path: ".",
        scripts: {
          build: "tsc"
        },
        devDependencies: {
          "@types/node": "~18.19.75"
        },
        get children() {
          return _$createComponent(ay.SourceDirectory, {
            path: "src",
            get children() {
              return [_$createComponent(ts.BarrelFile, {
                "export": "."
              }), _$createComponent(Client, {}), _$createComponent(ay.SourceDirectory, {
                path: "models",
                get children() {
                  return [_$createComponent(ts.BarrelFile, {
                    "export": "models"
                  }), _$createComponent(Models, {}), _$createComponent(ay.SourceDirectory, {
                    path: "internal",
                    get children() {
                      return _$createComponent(ModelSerializers, {});
                    }
                  })];
                }
              }), _$createComponent(ay.SourceDirectory, {
                path: "api",
                get children() {
                  return _$createComponent(OperationsDirectory, {});
                }
              }), _$createComponent(ay.SourceDirectory, {
                path: "helpers",
                get children() {
                  return [_$createComponent(Interfaces, {}), _$createComponent(MultipartHelpers, {}), _$createComponent(ts.SourceFile, {
                    path: "error.ts",
                    get children() {
                      return _$createComponent(RestError, {});
                    }
                  })];
                }
              })];
            }
          });
        }
      });
    }
  });
  await writeOutput(output, context.emitterOutputDir);
}
//# sourceMappingURL=emitter.js.map